@@ -57,7 +57,7 @@ Your paste title description.
 
 =head1 SEE ALSO
 
-L<https://metacpan.org/pod/WWW::Pastebin::PastebinCom::Create", L< https://metacpan.org/pod/App::Nopaste"
+L<https://metacpan.org/pod/WWW::Pastebin::PastebinCom::Create", L< https://metacpan.org/pod/App::Nopaste">
 
 
 =head1 AUTHOR
